---
name: 🚀 New feature
about: Request a new feature.
title: ''
labels: ''
assignees: ''
---

Before suggesting a new feature, please make sure this hasn't already been suggested by searching through the past issues and the PR tracker.

### Presentation of the new feature

Assume that we know nothing about this feature. Please give us as much information as possible so we can judge it fairly. That includes (but is not limited to):
- Academic article
- Blog posts
- Implementations
- Personnal experience with the feature

### Where does it fit in Outlines?

Please explain to us why you are suggesting this feature for integration in Outlines.

### Are you willing to open a PR?

Tell us whether you are willing to add the feature yourself, and if so if you can share a design plan. **You may be challenged.**

Thanks for contributing!
